@@ -11,6 +11,9 @@ from dataclasses import dataclass
 from typing import Self
 
 from lifx.const import (
+    DEFAULT_MAX_RETRIES,
+    DEFAULT_REQUEST_TIMEOUT,
+    DISCOVERY_TIMEOUT,
     LIFX_GROUP_NAMESPACE,
     LIFX_LOCATION_NAMESPACE,
     LIFX_UDP_PORT,
@@ -118,10 +121,10 @@ class Device:
     This class provides common functionality for all LIFX devices:
     - Connection management
     - Basic device queries (label, power, version, info)
-    - State storage with timestamps (no automatic expiration)
+    - State caching for reduced network traffic
 
-    All properties return a tuple of (value, timestamp) or None if never fetched.
-    Callers can use the timestamp to determine if data needs refreshing.
+    Properties return cached values or None if never fetched.
+    Use get_*() methods to fetch fresh data from the device.
 
     Example:
         ```python
@@ -132,19 +135,16 @@ class Device:
             label = await device.get_label()
             print(f"Device: {label}")
 
-            # Check label and its age
+            # Use cached label value
             if device.label is not None:
-                label_value, updated_at = device.label
-                age = time.time() - updated_at
-                print(f"Label '{label_value}' is {age:.1f}s old")
+                print(f"Cached label: {device.label}")
 
-            # Turn on device and auto-refresh power state
-            await device.set_power(True, refresh=True)
+            # Turn on device
+            await device.set_power(True)
 
-            # Get power state with timestamp
-            power_result = device.power
-            if power_result:
-                is_on, timestamp = power_result
+            # Get power state
+            is_on = await device.get_power()
+            if is_on is not None:
                 print(f"Power: {'ON' if is_on else 'OFF'}")
         ```
     """
@@ -154,8 +154,8 @@ class Device:
         serial: str,
         ip: str,
         port: int = LIFX_UDP_PORT,
-        timeout: float = 1.0,
-        max_retries: int = 3,
+        timeout: float = DEFAULT_REQUEST_TIMEOUT,
+        max_retries: int = DEFAULT_MAX_RETRIES,
     ) -> None:
         """Initialize device.
 
@@ -251,15 +251,14 @@ class Device:
             max_retries=max_retries,
         )
 
-        # State storage: Each value stored as (value, timestamp) tuple
-        # Values never expire automatically - caller decides when to refresh
-        self._label: tuple[str, float] | None = None
-        self._power: tuple[bool, float] | None = None
-        self._version: tuple[DeviceVersion, float] | None = None
-        self._host_firmware: tuple[FirmwareInfo, float] | None = None
-        self._wifi_firmware: tuple[FirmwareInfo, float] | None = None
-        self._location: tuple[LocationInfo, float] | None = None
-        self._group: tuple[GroupInfo, float] | None = None
+        # State storage: Cached values from device
+        self._label: str | None = None
+        self._version: DeviceVersion | None = None
+        self._host_firmware: FirmwareInfo | None = None
+        self._wifi_firmware: FirmwareInfo | None = None
+        self._location: LocationInfo | None = None
+        self._group: GroupInfo | None = None
+        self._mac_address: str | None = None
 
         # Product capabilities for device features (populated on first use)
         self._capabilities: ProductInfo | None = None
@@ -270,7 +269,7 @@ class Device:
         ip: str,
         port: int = LIFX_UDP_PORT,
         serial: str | None = None,
-        timeout: float = 1.0,
+        timeout: float = DEFAULT_REQUEST_TIMEOUT,
     ) -> Self:
         """Create and return an instance for the given IP address.
 
@@ -294,7 +293,9 @@ class Device:
         """
         if serial is None:
             temp_conn = DeviceConnection(serial="000000000000", ip=ip, port=port)
-            response = await temp_conn.request(packets.Device.GetService(), timeout=2.0)
+            response = await temp_conn.request(
+                packets.Device.GetService(), timeout=DISCOVERY_TIMEOUT
+            )
             if response and isinstance(response, packets.Device.StateService):
                 if temp_conn.serial and temp_conn.serial != "000000000000":
                     return cls(
@@ -328,10 +329,43 @@ class Device:
             tg.create_task(self.get_host_firmware())
             tg.create_task(self.get_wifi_firmware())
             tg.create_task(self.get_label())
-            tg.create_task(self.get_power())
             tg.create_task(self.get_location())
             tg.create_task(self.get_group())
 
+    def _calculate_mac_address(self) -> None:
+        """Calculate MAC address from serial and host firmware version.
+
+        The MAC address calculation depends on the major version of the host firmware:
+        - Version 2 or 4: MAC address matches the serial
+        - Version 3: MAC address is serial with LSB + 1 (with wraparound from FF to 00)
+        - Unknown versions: Default to serial
+
+        This method is called automatically when host firmware is fetched.
+        """
+        if self._host_firmware is None:
+            return
+
+        # Get serial bytes
+        serial_obj = Serial.from_string(self.serial)
+        serial_bytes = bytearray(serial_obj.value)
+
+        # Check firmware major version
+        major_version = self._host_firmware.version_major
+
+        if major_version in (2, 4):
+            # MAC address matches serial
+            mac_bytes = bytes(serial_bytes)
+        elif major_version == 3:
+            # Add 1 to least significant byte (with wraparound)
+            serial_bytes[5] = (serial_bytes[5] + 1) % 256
+            mac_bytes = bytes(serial_bytes)
+        else:
+            # For unknown versions, default to serial
+            mac_bytes = bytes(serial_bytes)
+
+        # Convert to colon-separated hex string format (e.g., "d0:73:d5:01:02:03")
+        self._mac_address = ":".join(f"{b:02x}" for b in mac_bytes)
+
     async def _ensure_capabilities(self) -> None:
         """Ensure device capabilities are populated.
 
@@ -407,17 +441,16 @@ class Device:
             label = await device.get_label()
             print(f"Device name: {label}")
 
-            # Or use stored value
+            # Or use cached value
             if device.label:
-                label, timestamp = device.label
-                print(f"Stored label: {label}")
+                print(f"Cached label: {device.label}")
             ```
         """
         # Request automatically unpacks and decodes label
         state = await self.connection.request(packets.Device.GetLabel())
 
-        # Store label with timestamp
-        self._label = (state.label, time.time())
+        # Store label
+        self._label = state.label
         _LOGGER.debug(
             {
                 "class": "Device",
@@ -458,8 +491,8 @@ class Device:
             packets.Device.SetLabel(label=label_bytes),
         )
 
-        # Update state with timestamp
-        self._label = (label, time.time())
+        # Update cached state
+        self._label = label
         _LOGGER.debug(
             {
                 "class": "Device",
@@ -494,7 +527,6 @@ class Device:
         # Power level is uint16 (0 or 65535)
         is_on = state.level > 0
 
-        self._power = (is_on, time.time())
         _LOGGER.debug(
             {
                 "class": "Device",
@@ -529,8 +561,6 @@ class Device:
             packets.Device.SetPower(level=level),
         )
 
-        # Update state with timestamp
-        self._power = (on, time.time())
         _LOGGER.debug(
             {
                 "class": "Device",
@@ -567,7 +597,7 @@ class Device:
             product=state.product,
         )
 
-        self._version = (version, time.time())
+        self._version = version
 
         _LOGGER.debug(
             {
@@ -682,7 +712,10 @@ class Device:
             version_minor=state.version_minor,
         )
 
-        self._host_firmware = (firmware, time.time())
+        self._host_firmware = firmware
+
+        # Calculate MAC address now that we have firmware info
+        self._calculate_mac_address()
 
         _LOGGER.debug(
             {
@@ -726,7 +759,7 @@ class Device:
             version_minor=state.version_minor,
         )
 
-        self._wifi_firmware = (firmware, time.time())
+        self._wifi_firmware = firmware
 
         _LOGGER.debug(
             {
@@ -771,7 +804,7 @@ class Device:
             updated_at=state.updated_at,
         )
 
-        self._location = (location, time.time())
+        self._location = location
 
         _LOGGER.debug(
             {
@@ -787,7 +820,9 @@ class Device:
         )
         return location
 
-    async def set_location(self, label: str, *, discover_timeout: float = 3.0) -> None:
+    async def set_location(
+        self, label: str, *, discover_timeout: float = DISCOVERY_TIMEOUT
+    ) -> None:
         """Set device location information.
 
         Automatically discovers devices on the network to check if any device already
@@ -797,7 +832,7 @@ class Device:
 
         Args:
             label: Location label (max 32 characters)
-            discover_timeout: Timeout for device discovery in seconds (default 3.0)
+            discover_timeout: Timeout for device discovery in seconds
 
         Raises:
             LifxDeviceNotFoundError: If device is not connected
@@ -894,11 +929,11 @@ class Device:
             ),
         )
 
-        # Update state with timestamp
+        # Update cached state
         location_info = LocationInfo(
             location=location_uuid_to_use, label=label, updated_at=updated_at
         )
-        self._location = (location_info, time.time())
+        self._location = location_info
         _LOGGER.debug(
             {
                 "class": "Device",
@@ -941,7 +976,7 @@ class Device:
             updated_at=state.updated_at,
         )
 
-        self._group = (group, time.time())
+        self._group = group
 
         _LOGGER.debug(
             {
@@ -957,7 +992,9 @@ class Device:
         )
         return group
 
-    async def set_group(self, label: str, *, discover_timeout: float = 3.0) -> None:
+    async def set_group(
+        self, label: str, *, discover_timeout: float = DISCOVERY_TIMEOUT
+    ) -> None:
         """Set device group information.
 
         Automatically discovers devices on the network to check if any device already
@@ -967,7 +1004,7 @@ class Device:
 
         Args:
             label: Group label (max 32 characters)
-            discover_timeout: Timeout for device discovery in seconds (default 3.0)
+            discover_timeout: Timeout for device discovery in seconds
 
         Raises:
             LifxDeviceNotFoundError: If device is not connected
@@ -1064,11 +1101,11 @@ class Device:
             ),
         )
 
-        # Update state with timestamp
+        # Update cached state
         group_info = GroupInfo(
             group=group_uuid_to_use, label=label, updated_at=updated_at
         )
-        self._group = (group_info, time.time())
+        self._group = group_info
         _LOGGER.debug(
             {
                 "class": "Device",
@@ -1117,83 +1154,74 @@ class Device:
         )
 
     @property
-    def label(self) -> tuple[str, float] | None:
-        """Get stored label with timestamp if available.
+    def label(self) -> str | None:
+        """Get cached label if available.
 
         Use get_label() to fetch from device.
 
         Returns:
-            Tuple of (label, timestamp) or None if never fetched.
+            Device label or None if never fetched.
         """
         return self._label
 
     @property
-    def power(self) -> tuple[bool, float] | None:
-        """Get stored power state with timestamp if available.
-
-        Use get_power() to fetch from device.
-
-        Returns:
-            Tuple of (is_on, timestamp) or None if never fetched.
-        """
-        return self._power
-
-    @property
-    def version(self) -> tuple[DeviceVersion, float] | None:
-        """Get stored version with timestamp if available.
+    def version(self) -> DeviceVersion | None:
+        """Get cached version if available.
 
         Use get_version() to fetch from device.
 
         Returns:
-            Tuple of (device_version, timestamp) or None if never fetched.
+            Device version or None if never fetched.
         """
         return self._version
 
     @property
-    def host_firmware(self) -> tuple[FirmwareInfo, float] | None:
-        """Get stored host firmware with timestamp if available.
+    def host_firmware(self) -> FirmwareInfo | None:
+        """Get cached host firmware if available.
 
         Use get_host_firmware() to fetch from device.
 
         Returns:
-            Tuple of (firmware_info, timestamp) or None if never fetched.
+            Firmware info or None if never fetched.
         """
         return self._host_firmware
 
     @property
-    def wifi_firmware(self) -> tuple[FirmwareInfo, float] | None:
-        """Get stored wifi firmware with timestamp if available.
+    def wifi_firmware(self) -> FirmwareInfo | None:
+        """Get cached wifi firmware if available.
 
         Use get_wifi_firmware() to fetch from device.
 
         Returns:
-            Tuple of (firmware_info, timestamp) or None if never fetched.
+            Firmware info or None if never fetched.
         """
         return self._wifi_firmware
 
     @property
-    def location(self) -> tuple[str, float] | None:
-        """Get stored location name with timestamp if available.
+    def location(self) -> str | None:
+        """Get cached location name if available.
 
         Use get_location() to fetch from device.
 
         Returns:
-            Tuple of (location_name, timestamp) or None if never fetched.
+            Location name or None if never fetched.
         """
         if self._location is not None:
-            return self._location[0].label, self._location[1]
+            return self._location.label
+        return None
 
     @property
-    def group(self) -> tuple[str, float] | None:
-        """Get stored group name with timestamp if available.
+    def group(self) -> str | None:
+        """Get cached group name if available.
 
         Use get_group() to fetch from device.
 
         Returns:
-            Tuple of (group_name, timestamp) or None if never fetched.
+            Group name or None if never fetched.
         """
         if self._group is not None:
-            return self._group[0].label, self._group[1]
+            return self._group.label
+        return None
 
     @property
     def model(self) -> str | None:
@@ -1205,6 +1233,18 @@ class Device:
         if self.capabilities is not None:
             return self.capabilities.name
 
+    @property
+    def mac_address(self) -> str | None:
+        """Get cached MAC address if available.
+
+        Use get_host_firmware() to calculate MAC address from device firmware.
+
+        Returns:
+            MAC address in colon-separated format (e.g., "d0:73:d5:01:02:03"),
+            or None if not yet calculated.
+        """
+        return self._mac_address
+
     def __repr__(self) -> str:
         """String representation of device."""
         return f"Device(serial={self.serial}, ip={self.ip}, port={self.port})"
