@@ -3,12 +3,16 @@
 from __future__ import annotations
 
 import logging
+from typing import TYPE_CHECKING
 
 from lifx.color import HSBK
 from lifx.devices.base import Device
 from lifx.protocol import packets
 from lifx.protocol.protocol_types import LightWaveform
 
+if TYPE_CHECKING:
+    from lifx.theme import Theme
+
 _LOGGER = logging.getLogger(__name__)
 
 
@@ -46,8 +50,6 @@ class Light(Device):
     def __init__(self, *args, **kwargs) -> None:
         """Initialize Light with additional state attributes."""
         super().__init__(*args, **kwargs)
-        # Light-specific state storage
-        self._color: tuple[HSBK, float] | None = None
 
     async def _setup(self) -> None:
         """Populate light capabilities, state and metadata."""
@@ -86,13 +88,8 @@ class Light(Device):
         power = state.power > 0
         label = state.label
 
-        # Store color and other fields from StateColor response with timestamps
-        import time
-
-        timestamp = time.time()
-        self._color = (color, timestamp)
-        self._label = (label, timestamp)  # Already decoded to string
-        self._power = (power, timestamp)
+        # Store label from StateColor response
+        self._label = label  # Already decoded to string
 
         _LOGGER.debug(
             {
@@ -150,10 +147,6 @@ class Light(Device):
             ),
         )
 
-        # Update state with timestamp
-        import time
-
-        self._color = (color, time.time())
         _LOGGER.debug(
             {
                 "class": "Device",
@@ -195,14 +188,21 @@ class Light(Device):
                 f"Brightness must be between 0.0 and 1.0, got {brightness}"
             )
 
-        # Get current color
-        current_color, _, _ = await self.get_color()
+        # Use set_waveform_optional with HALF_SINE waveform to set brightness
+        # without needing to query current color values. Convert duration to seconds.
+        color = HSBK(hue=0, saturation=0, brightness=brightness, kelvin=3500)
 
-        # Create new color with modified brightness
-        new_color = current_color.with_brightness(brightness)
-
-        # Set the new color
-        await self.set_color(new_color, duration=duration)
+        await self.set_waveform_optional(
+            color=color,
+            period=max(duration, 0.001),
+            cycles=1,
+            waveform=LightWaveform.HALF_SINE,
+            transient=False,
+            set_hue=False,
+            set_saturation=False,
+            set_brightness=True,
+            set_kelvin=False,
+        )
 
     async def set_kelvin(self, kelvin: int, duration: float = 0.0) -> None:
         """Set light color temperature, preserving brightness. Saturation is
@@ -229,14 +229,21 @@ class Light(Device):
         if not (HSBK.MIN_KELVIN <= kelvin <= HSBK.MAX_KELVIN):
             raise ValueError(f"Kelvin must be 1500-9000, got {kelvin}")
 
-        # Get current color
-        current_color, _, _ = await self.get_color()
+        # Use set_waveform_optional with HALF_SINE waveform to set kelvin
+        # and saturation without needing to query current color values
+        color = HSBK(hue=0, saturation=0, brightness=1.0, kelvin=kelvin)
 
-        # Create new color with modified temperature and no saturation
-        new_color = current_color.with_kelvin(kelvin).with_saturation(0)
-
-        # Set the new color
-        await self.set_color(new_color, duration=duration)
+        await self.set_waveform_optional(
+            color=color,
+            period=max(duration, 0.001),
+            cycles=1,
+            waveform=LightWaveform.HALF_SINE,
+            transient=False,
+            set_hue=False,
+            set_saturation=True,
+            set_brightness=False,
+            set_kelvin=True,
+        )
 
     async def set_hue(self, hue: float, duration: float = 0.0) -> None:
         """Set light hue only, preserving saturation, brightness, and temperature.
@@ -265,14 +272,21 @@ class Light(Device):
                 f"Hue must be between {HSBK.MIN_HUE} and {HSBK.MAX_HUE}, got {hue}"
             )
 
-        # Get current color
-        current_color, _, _ = await self.get_color()
+        # Use set_waveform_optional with HALF_SINE waveform to set hue
+        # without needing to query current color values
+        color = HSBK(hue=hue, saturation=1.0, brightness=1.0, kelvin=3500)
 
-        # Create new color with modified hue
-        new_color = current_color.with_hue(hue)
-
-        # Set the new color
-        await self.set_color(new_color, duration=duration)
+        await self.set_waveform_optional(
+            color=color,
+            period=max(duration, 0.001),
+            cycles=1,
+            waveform=LightWaveform.HALF_SINE,
+            transient=False,
+            set_hue=True,
+            set_saturation=False,
+            set_brightness=False,
+            set_kelvin=False,
+        )
 
     async def set_saturation(self, saturation: float, duration: float = 0.0) -> None:
         """Set light saturation only, preserving hue, brightness, and temperature.
@@ -298,14 +312,21 @@ class Light(Device):
         if not (HSBK.MIN_SATURATION <= saturation <= HSBK.MAX_SATURATION):
             raise ValueError(f"Saturation must be 0.0-1.0, got {saturation}")
 
-        # Get current color
-        current_color, _, _ = await self.get_color()
+        # Use set_waveform_optional with HALF_SINE waveform to set saturation
+        # without needing to query current color values
+        color = HSBK(hue=0, saturation=saturation, brightness=1.0, kelvin=3500)
 
-        # Create new color with modified saturation
-        new_color = current_color.with_saturation(saturation)
-
-        # Set the new color
-        await self.set_color(new_color, duration=duration)
+        await self.set_waveform_optional(
+            color=color,
+            period=max(duration, 0.001),
+            cycles=1,
+            waveform=LightWaveform.HALF_SINE,
+            transient=False,
+            set_hue=False,
+            set_saturation=True,
+            set_brightness=False,
+            set_kelvin=False,
+        )
 
     async def get_power(self) -> bool:
         """Get light power state (specific to light, not device).
@@ -335,10 +356,6 @@ class Light(Device):
         # Power level is uint16 (0 or 65535)
         is_on = state.level > 0
 
-        import time
-
-        self._power = (is_on, time.time())
-
         _LOGGER.debug(
             {
                 "class": "Device",
@@ -384,10 +401,6 @@ class Light(Device):
             packets.Light.SetPower(level=level, duration=duration_ms),
         )
 
-        # Update state with timestamp
-        import time
-
-        self._power = (on, time.time())
         _LOGGER.debug(
             {
                 "class": "Device",
@@ -674,17 +687,7 @@ class Light(Device):
             transient=True,
         )
 
-    # Stored value properties
-    @property
-    def color(self) -> tuple[HSBK, float] | None:
-        """Get stored light color with timestamp if available.
-
-        Returns:
-            Tuple of (color, timestamp) or None if never fetched.
-            Use get_color() to fetch from device.
-        """
-        return self._color
-
+    # Cached value properties
     @property
     def min_kelvin(self) -> int | None:
         """Get the minimum supported kelvin value if available.
@@ -711,6 +714,50 @@ class Light(Device):
         ):
             return self.capabilities.temperature_range.max
 
+    async def apply_theme(
+        self,
+        theme: Theme,
+        power_on: bool = False,
+        duration: float = 0.0,
+    ) -> None:
+        """Apply a theme to this light.
+
+        Selects a random color from the theme and applies it to the light.
+
+        Args:
+            theme: Theme to apply
+            power_on: Turn on the light
+            duration: Transition duration in seconds
+
+        Example:
+            ```python
+            from lifx.theme import get_theme
+
+            theme = get_theme("evening")
+            await light.apply_theme(theme, power_on=True, duration=0.5)
+            ```
+        """
+        if self.capabilities is None:
+            await self._ensure_capabilities()
+
+        if self.capabilities and not self.capabilities.has_color:
+            return
+
+        # Select a random color from theme
+        color = theme.random()
+
+        # Check if light is on
+        is_on = await self.get_power()
+
+        # Apply color to light
+        # If light is off and we're turning it on, set color immediately then fade on
+        if power_on and not is_on:
+            await self.set_color(color, duration=0)
+            await self.set_power(True, duration=duration)
+        else:
+            # Light is already on, or we're not turning it on - apply with duration
+            await self.set_color(color, duration=duration)
+
     def __repr__(self) -> str:
         """String representation of light."""
         return f"Light(serial={self.serial}, ip={self.ip}, port={self.port})"
