@@ -5,6 +5,7 @@ from __future__ import annotations
 import asyncio
 import logging
 from dataclasses import dataclass
+from typing import TYPE_CHECKING
 
 from lifx.color import HSBK
 from lifx.devices.light import Light
@@ -13,10 +14,14 @@ from lifx.protocol.protocol_types import (
     TileBufferRect,
     TileEffectParameter,
     TileEffectSettings,
+    TileEffectSkyType,
     TileEffectType,
 )
 from lifx.protocol.protocol_types import TileStateDevice as LifxProtocolTileDevice
 
+if TYPE_CHECKING:
+    from lifx.theme import Theme
+
 _LOGGER = logging.getLogger(__name__)
 
 
@@ -83,7 +88,8 @@ class TileEffect:
         speed: Effect speed in milliseconds
         duration: Total effect duration in nanoseconds (0 for infinite)
         palette: Color palette for the effect (max 16 colors)
-        parameters: Effect-specific parameters (8 uint32 values)
+        parameters: Effect-specific parameters (sky_type, cloud_saturation_min,
+                    cloud_saturation_max)
     """
 
     effect_type: TileEffectType
@@ -99,7 +105,7 @@ class TileEffect:
             # Default palette: single white color
             self.palette = [HSBK(0, 0, 1.0, 3500)]
         if self.parameters is None:
-            self.parameters = [0] * 8
+            self.parameters = [0] * 3
 
         # Validate all fields
         self._validate_speed(self.speed)
@@ -155,20 +161,18 @@ class TileEffect:
         """Validate effect parameters list.
 
         Args:
-            value: List of 8 uint32 parameters
+            value: sky_type, cloud_saturation_min, cloud_saturation_max
 
         Raises:
             ValueError: If parameters list is invalid
         """
-        if len(value) != 8:
+        if len(value) != 3:
             raise ValueError(
-                f"Effect parameters must be a list of 8 values, got {len(value)}"
+                f"Effect parameters must be a list of 3 values, got {len(value)}"
             )
         for i, param in enumerate(value):
-            if not (0 <= param < 2**32):
-                raise ValueError(
-                    f"Parameter {i} must be a uint32 (0-{2**32 - 1}), got {param}"
-                )
+            if not (0 <= param < 256):
+                raise ValueError(f"Parameter {i} must be a uint8 (0-255), got {param}")
 
 
 @dataclass
@@ -361,11 +365,8 @@ class TileDevice(Light):
         """Initialize TileDevice with additional state attributes."""
         super().__init__(*args, **kwargs)
         # Tile-specific state storage
-        self._tile_chain: tuple[list[TileInfo], float] | None = None
-        self._tile_effect: tuple[TileEffect | None, float] | None = None
-        # Tile colors: dict indexed by tile_index with TileColors for each tile
-        # Structure: dict[tile_index] -> TileColors(colors, width, height)
-        self._tile_colors: tuple[dict[int, TileColors], float] | None = None
+        self._tile_chain: list[TileInfo] | None = None
+        self._tile_effect: TileEffect | None | None = None
 
     async def _setup(self) -> None:
         """Populate Tile light capabilities, state and metadata."""
@@ -375,7 +376,7 @@ class TileDevice(Light):
             tg.create_task(self.get_tile_effect())
         async with asyncio.TaskGroup() as tg:
             if self.tile_count is not None:
-                tile_count, _ = self.tile_count
+                tile_count = self.tile_count
             else:
                 tile_count = await self.get_tile_count()
             [tg.create_task(self.get_tile_colors(i)) for i in range(tile_count)]
@@ -410,9 +411,7 @@ class TileDevice(Light):
             for tile_device in state.tile_devices[: state.tile_devices_count]
         ]
 
-        import time
-
-        self._tile_chain = (tiles, time.time())
+        self._tile_chain = tiles
 
         _LOGGER.debug(
             {
@@ -599,48 +598,6 @@ class TileDevice(Light):
                     row.append(HSBK(0, 0, 0, 3500))
             colors_2d.append(row)
 
-        # Update tile colors with fetched data
-        import time
-
-        timestamp = time.time()
-
-        # Get tile chain to know dimensions
-        if self._tile_chain is None:
-            chain = await self.get_tile_chain()
-        else:
-            chain, _ = self._tile_chain
-
-        # Get tile info for this specific tile
-        tile_info = chain[tile_index]
-
-        # Initialize or get existing colors dict
-        if self._tile_colors is None:
-            tiles_colors_dict = {}
-        else:
-            tiles_colors_dict, _ = self._tile_colors
-
-        # Get or create TileColors for this tile
-        if tile_index not in tiles_colors_dict:
-            # Create new TileColors with default black colors
-            num_zones = tile_info.width * tile_info.height
-            default_colors = [HSBK(0, 0, 0, 3500)] * num_zones
-            tiles_colors_dict[tile_index] = TileColors(
-                colors=default_colors, width=tile_info.width, height=tile_info.height
-            )
-
-        tile_colors = tiles_colors_dict[tile_index]
-
-        # Update the specific tile region with fetched colors
-        for row_idx in range(height):
-            for col_idx in range(width):
-                tile_x = x + col_idx
-                tile_y = y + row_idx
-                if tile_y < tile_colors.height and tile_x < tile_colors.width:
-                    tile_colors.set_color(tile_x, tile_y, colors_2d[row_idx][col_idx])
-
-        # Store updated colors with new timestamp
-        self._tile_colors = (tiles_colors_dict, timestamp)
-
         _LOGGER.debug(
             {
                 "class": "Device",
@@ -729,12 +686,7 @@ class TileDevice(Light):
 
         # Check power state to optimize duration handling
         # If device is off, set colors instantly then power on with duration
-        # Use stored power state if available, otherwise fetch
-        power_tuple = self.power
-        if power_tuple is not None:
-            is_powered_on, _ = power_tuple
-        else:
-            is_powered_on = await self.get_power()
+        is_powered_on = await self.get_power()
 
         # Convert duration to milliseconds
         duration_ms = int(duration * 1000)
@@ -808,48 +760,6 @@ class TileDevice(Light):
                 duration=copy_duration,
             )
 
-        # Update tile colors with the values we just set
-        import time
-
-        timestamp = time.time()
-
-        # Get tile chain to know dimensions
-        if self._tile_chain is None:
-            chain = await self.get_tile_chain()
-        else:
-            chain, _ = self._tile_chain
-
-        # Get tile info for this specific tile
-        tile_info = chain[tile_index]
-
-        # Initialize or get existing colors dict
-        if self._tile_colors is None:
-            tiles_colors_dict = {}
-        else:
-            tiles_colors_dict, _ = self._tile_colors
-
-        # Get or create TileColors for this tile
-        if tile_index not in tiles_colors_dict:
-            # Create new TileColors with default black colors
-            num_zones = tile_info.width * tile_info.height
-            default_colors = [HSBK(0, 0, 0, 3500)] * num_zones
-            tiles_colors_dict[tile_index] = TileColors(
-                colors=default_colors, width=tile_info.width, height=tile_info.height
-            )
-
-        tile_colors = tiles_colors_dict[tile_index]
-
-        # Update the specific tile region with colors we just set
-        for row_idx in range(height):
-            for col_idx in range(width):
-                tile_x = x + col_idx
-                tile_y = y + row_idx
-                if tile_y < tile_colors.height and tile_x < tile_colors.width:
-                    tile_colors.set_color(tile_x, tile_y, colors[row_idx][col_idx])
-
-        # Store updated colors with new timestamp
-        self._tile_colors = (tiles_colors_dict, timestamp)
-
         _LOGGER.debug(
             {
                 "class": "Device",
@@ -900,14 +810,9 @@ class TileDevice(Light):
 
         # Extract parameters from the settings parameter field
         parameters = [
-            settings.parameter.parameter0,
-            settings.parameter.parameter1,
-            settings.parameter.parameter2,
-            settings.parameter.parameter3,
-            settings.parameter.parameter4,
-            settings.parameter.parameter5,
-            settings.parameter.parameter6,
-            settings.parameter.parameter7,
+            int(settings.parameter.sky_type),
+            settings.parameter.cloud_saturation_min,
+            settings.parameter.cloud_saturation_max,
         ]
 
         # Convert palette from protocol HSBK to HSBK
@@ -927,9 +832,7 @@ class TileDevice(Light):
                 parameters=parameters,
             )
 
-        import time
-
-        self._tile_effect = (result, time.time())
+        self._tile_effect = result
 
         _LOGGER.debug(
             {
@@ -982,14 +885,15 @@ class TileDevice(Light):
 
         # Convert palette to protocol HSBK and pad to 16
         protocol_palette = [color.to_protocol() for color in palette]
+
         while len(protocol_palette) < 16:
             protocol_palette.append(HSBK(0, 0, 0, 3500).to_protocol())
 
-        # Ensure parameters list is 8 elements
-        parameters = effect.parameters or [0] * 8
-        if len(parameters) < 8:
-            parameters.extend([0] * (8 - len(parameters)))
-        parameters = parameters[:8]
+        # Ensure parameters list is 3 elements (sky_type, cloud_sat_min, cloud_sat_max)
+        parameters = effect.parameters or [0] * 3
+        if len(parameters) < 3:
+            parameters.extend([0] * (3 - len(parameters)))
+        parameters = parameters[:3]
 
         # Request automatically handles acknowledgement
         await self.connection.request(
@@ -1000,14 +904,9 @@ class TileDevice(Light):
                     speed=effect.speed,
                     duration=effect.duration,
                     parameter=TileEffectParameter(
-                        parameter0=parameters[0],
-                        parameter1=parameters[1],
-                        parameter2=parameters[2],
-                        parameter3=parameters[3],
-                        parameter4=parameters[4],
-                        parameter5=parameters[5],
-                        parameter6=parameters[6],
-                        parameter7=parameters[7],
+                        sky_type=TileEffectSkyType(value=parameters[0]),
+                        cloud_saturation_min=parameters[1],
+                        cloud_saturation_max=parameters[2],
                     ),
                     palette_count=len(palette),
                     palette=protocol_palette,
@@ -1015,11 +914,9 @@ class TileDevice(Light):
             ),
         )
 
-        # Update state attribute
-        import time
-
+        # Update cached state
         result = effect if effect.effect_type != TileEffectType.OFF else None
-        self._tile_effect = (result, time.time())
+        self._tile_effect = result
 
         _LOGGER.debug(
             {
@@ -1314,60 +1211,110 @@ class TileDevice(Light):
             }
         )
 
-    # Stored value properties
+    # Cached value properties
     @property
-    def tile_chain(self) -> tuple[list[TileInfo], float] | None:
-        """Get stored tile chain if available.
+    def tile_chain(self) -> list[TileInfo] | None:
+        """Get cached tile chain if available.
 
         Returns:
-            Stored tile chain (use get_tile_chain() for fresh data)
+            Tile chain or None if never fetched (use get_tile_chain() for fresh data)
         """
         return self._tile_chain
 
     @property
-    def tile_count(self) -> tuple[int, float] | None:
-        """Get stored tile count with timestamp if available.
+    def tile_count(self) -> int | None:
+        """Get cached tile count if available.
 
         Returns:
-            Tuple of (tile_count, timestamp) or None if never fetched.
+            Tile count or None if never fetched.
             Derived from tile_chain property.
         """
         if self._tile_chain is not None:
-            chain, timestamp = self._tile_chain
-            return (len(chain), timestamp)
+            return len(self._tile_chain)
         return None
 
     @property
-    def tile_effect(self) -> tuple[TileEffect | None, float] | None:
-        """Get stored tile effect if available.
+    def tile_effect(self) -> TileEffect | None | None:
+        """Get cached tile effect if available.
 
         Returns:
-            Stored tile effect (use get_tile_effect() for fresh data)
+            Tile effect or None if never fetched (use get_tile_effect() for fresh data)
         """
         return self._tile_effect
 
-    @property
-    def tile_colors(self) -> tuple[dict[int, TileColors], float] | None:
-        """Get stored tile colors with timestamp if available.
+    async def apply_theme(
+        self,
+        theme: Theme,
+        power_on: bool = False,
+        duration: float = 0.0,
+    ) -> None:
+        """Apply a theme to this tile device.
 
-        Returns:
-            Tuple of (tile_colors_dict, timestamp) or None if never fetched.
-            The dict maps tile_index -> TileColors(colors, width, height).
-            Each TileColors contains a flat list of colors and dimensions.
-            Use get_tile_colors() to fetch from device.
+        Distributes theme colors across all tiles in the chain using Canvas-based
+        rendering to create natural color splotches that grow outward.
+
+        Args:
+            theme: Theme to apply
+            power_on: Turn on the device
+            duration: Transition duration in seconds
 
         Example:
             ```python
-            if tile.tile_colors:
-                colors_dict, timestamp = tile.tile_colors
-                tile_0 = colors_dict[0]
-                # Access flat list: tile_0.colors
-                # Get dimensions: tile_0.width, tile_0.height
-                # Get 2D array: tile_0.to_2d()
-                # Get specific color: tile_0.get_color(x, y)
+            from lifx.theme import get_theme
+
+            theme = get_theme("sunset")
+            await tile.apply_theme(theme, power_on=True, duration=2.0)
             ```
         """
-        return self._tile_colors
+        from lifx.theme.generators import MatrixGenerator
+
+        # Get tile dimensions
+        tiles = await self.get_tile_chain()
+        if not tiles:
+            _LOGGER.warning("No tiles available, skipping theme application")
+            return
+
+        # Build coords_and_sizes for all tiles
+        left_x = 0
+        coords_and_sizes = []
+        for tile in tiles:
+            coords_and_sizes.append(((left_x, 0), (tile.width, tile.height)))
+            left_x += tile.width
+
+        # Create generator with all tile coordinates
+        generator = MatrixGenerator(coords_and_sizes)
+
+        # Generate colors for all tiles at once
+        tile_colors_list = generator.get_theme_colors(theme)
+
+        # Check if device is on
+        is_on = await self.get_power()
+
+        # Determine duration for color setting
+        color_duration = 0 if (power_on and not is_on) else duration
+
+        # Apply colors to each tile
+        for tile_idx, colors_flat in enumerate(tile_colors_list):
+            tile_info = tiles[tile_idx]
+
+            # Convert to 2D grid for set_tile_colors
+            colors_2d = []
+            for y in range(tile_info.height):
+                row = []
+                for x in range(tile_info.width):
+                    idx = y * tile_info.width + x
+                    if idx < len(colors_flat):
+                        row.append(colors_flat[idx])
+                    else:
+                        row.append(HSBK(0, 0, 1.0, 3500))  # White fallback
+                colors_2d.append(row)
+
+            # Apply colors to tile
+            await self.set_tile_colors(tile_idx, colors_2d, duration=color_duration)
+
+        # Turn on if requested
+        if power_on and not is_on:
+            await self.set_power(True, duration=duration)
 
     def __repr__(self) -> str:
         """String representation of tile device."""
